Learn R Programming

adaptiveGPCA (version 0.1.3)

check_phyloseq: Check compatibility of agpca and phyloseq objects

Description

Check that the dimensions of the agpca object match the phyloseq object and that the phyloseq object has a taxonomy table and a phylogenetic tree.

Usage

check_phyloseq(agpcafit, physeq)

Arguments

agpcafit

An adaptivegpca object.

physeq

A phyloseq object.