Learn R Programming

adaptiveGPCA (version 0.1.3)

varianceOnEvecs: Variance along eigenvectors of Q

Description

Project the sample points stored in the rows of X along the eigenvectors of Q and find the variance along each of the projections.

Usage

varianceOnEvecs(X, Q)

Value

A vector containing the variance of the samples along each of the eigenvectors of Q.

Arguments

X

An \(n \times p\) data matrix, each row corresponding to a sample.

Q

A \(p \times p\) similarity matrix, either as a matrix or as its eigendecomposition (the output from eigen).

Examples

Run this code
data(AntibioticSmall)
voe = varianceOnEvecs(AntibioticSmall$X, AntibioticSmall$Q)

Run the code above in your browser using DataLab