powered by
Project the sample points stored in the rows of X along the eigenvectors of Q and find the variance along each of the projections.
X
Q
varianceOnEvecs(X, Q)
A vector containing the variance of the samples along each of the eigenvectors of Q.
An \(n \times p\) data matrix, each row corresponding to a sample.
A \(p \times p\) similarity matrix, either as a matrix or as its eigendecomposition (the output from eigen).
eigen
data(AntibioticSmall) voe = varianceOnEvecs(AntibioticSmall$X, AntibioticSmall$Q)
Run the code above in your browser using DataLab